/*
 * Sungka v0.10.
 * DefaultArgsGen.java - Board Default Argument Generator
 * Copyright (c) 2003 Michael Barrientos. All rights reserved.
 */

/**
 * DefaultArgsGen implements a default argument generator for methods called by
 * the game board. Many methods do not need to customize their arguments for
 * each player. This class allows such methods to just pass in an arguments
 * array that will be the same for each player.
 *
 * @author Michael Barrientos
 * @version 0.10, 3/4/2003
 */
public class DefaultArgsGen implements SungkaArgsGen {
	/** The object array that we return every time. */
	private Object[] retVal;

	/**
	 * Constructs a default argument generator.
	 * @param retVal An Object array that we return each time getArgs is called.
	 */
	DefaultArgsGen(Object[] retVal) {
		this.retVal = retVal;
	}

	/**
	 * Returns the arguments for an associated method for this player.
	 * @param s The SungkaBoardServant object associated with a player.
	 * @return An Object array containing the arguments for a related function
	 *         as specified by Java reflection. For DefaultArgsGen, this will
	 *         always be the array that was given to us in the constructor.
	 */
	public Object[] getArgs(SungkaBoardServant s) {
		return retVal;
	}
}
