/*
 * Sungka v0.10.
 * SungkaArgsGen.java - Board Argument Generator interface
 * Copyright (c) 2003 Michael Barrientos. All rights reserved.
 */

/**
 * SungkaArgsGen specifies an interface for creating the arguments for a
 * related method.
 *
 * Within the game board, some of the functions to notify players of game
 * updates require different values to be sent to each player. This interface
 * provides a mechanism to get different arguments for each player.
 *
 * When this interface is implemented, the method provides it's own constructor
 * to get all the necessary information to create the arguments. The argument
 * generator is then called for each player, supplying that player's associated
 * SungkaBoardServant as an argument.
 *
 * @author Michael Barrientos
 * @version 0.10, 3/4/2003
 */
public interface SungkaArgsGen {
	/**
	 * Returns the arguments for an associated method for this player.
	 * @param s The SungkaBoardServant object associated with a player.
	 * @return An Object array containing the arguments for a related function
	 *         as specified by Java reflection.
	 */
	public Object[] getArgs(SungkaBoardServant s);
}
