/*
 * Sungka v0.10.
 * SungkaGameType.java - Sungka game rules holder
 * Copyright (c) 2003 Michael Barrientos. All rights reserved.
 */

/**
 * SungkaGameType describes the rules of a variation of Sungka. Each instance
 * stores the information about number of player, number of cups, and number
 * of stones for each game. Future expansion will let this hold more rules.
 * This class is used to give a user some preset game types to have a game
 * server host.
 *
 * FIXME: Make SungkaRegisterServant to take a SungkaGameType in constructor
 *
 * @author Michael Barrientos
 * @version 0.10, 3/4/2003
 */
public class SungkaGameType {
	/** The name of this Sungka variation. (e.g. Mancala) */
	private String name;

	/** The number of players in this variation */
	private int numPlayers;

	/** The number of cups per player in this variation */
	private int numCups;

	/** The initial number of stones per cup in this variation. */
	private int numStones;

	/**
	 * Constructs a new Sungka game variation.
	 * @param name The name of this Sungka game variation.
	 * @param numPlayer The number of players in this variation.
	 * @param numCups The number of cups per player in this variation.
	 * @param numStones The initial number of stones per cup in this variation.
	 */
	public SungkaGameType(String name, int numPlayers, int numCups, int numStones) {
		this.name = name;
		this.numPlayers = numPlayers;
		this.numCups = numCups;
		this.numStones = numStones;
	}

	/**
	 * Returns the name of this Sungka game variation.
	 * @return The name.
	 */
	public String getName() {
		return name;
	}

	/**
	 * Returns the number of participants in this game variation.
	 * @return The number of participants.
	 */
	public int getNumPlayers() {
		return numPlayers;
	}

	/**
	 * Returns the number of cups per player in this game variation.
	 * @return The number of cups per player
	 */
	public int getNumCups() {
		return numCups;
	}

	/**
	 * Returns the initial number of stones per cup in this game variation.
	 * @return The initial number of stone per cup.
	 */
	public int getNumStones() {
		return numStones;
	}

	/**
	 * Returns a String representation of this Game Type. This will return
	 * just the name of this game type.
	 */
	public String toString() {
		return name;
	}
}
