/*
 * Sungka v0.10.
 * SungkaPlayerInfo.java - Player information holder for player class
 * Copyright (c) 2003 Michael Barrientos. All rights reserved.
 */

/**
 * SungkaPlayerInfo holds information about a player playing in the current
 * game. Each instance holds the player's name, player number, and the order
 * that the player takes it turn.
 */
public class SungkaPlayerInfo implements Comparable {
	private String name;
	private int player;
	private int order;

	/**
	 * Constructs a new SungkaPlayerInfo that represents the given player
	 * @param name The user name of the player
	 * @param player The player number of the player
	 * @param order The order that this player plays in, -1 if an observer
	 */
	SungkaPlayerInfo(String name, int player, int order) {
		this.name = name;
		this.player = player;
		this.order = order;
	}

	/**
	 * Compares this SungkaPlayerInfo object to another object. If the object
	 * is a SungkaPlayerInfo, this function returns a number such that their
	 * player numbers are sorted. Otherwise, it throws a ClassCastException (as
	 * SungkaPlayerInfo objects are only comparable to other SungkaPlayerInfo
	 * objects).
	 * @param o the Object to be compared
	 * @return the value 0 if the argument is a SungkaPlayerInfo whose player
	 *         number is numerically equal to this SungkaPlayerInfo;
	 *         a value less than 0 if the argument is a SungkaPlayerInfo whose
	 *         player number is numerically greater than this SungkaPlayerInfo;
	 *         and a value greater than 0 if the argument is a SungkaPlayerInfo
	 *         whose player number is numerically less than this SungkaPlayerInfo.
	 * @throws ClassCastException if the argument is not a SungkaPlayerInfo.
	 */
	public int compareTo(Object o) {
		return player - ((SungkaPlayerInfo)o).player;
	}

	/**
	 * Returns whether or not this player is an observer.
	 * @return True if this player is an observer.
	 */
	public boolean isObserver() {
		return order < 0;
	}

	/**
	 * Returns the name of this player.
	 * @return The name of this player.
	 */
	public String getName() {
		return name;
	}

	/**
	 * Returns the player number of this player.
	 * @return The player number of this player.
	 */
	public int getPlayerNumber() {
		return player;
	}

	/**
	 * Returns the order that this player takes its turns in.
	 * @return The order of this player.
	 */
	public int getOrder() {
		return order;
	}
}
