/*
 * Sungka v0.10.
 * SungkaRegisterLogDialog.java - Game board log dialog box
 * Copyright (c) 2003 Michael Barrientos. All rights reserved.
 */
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.text.*;


/**
 * A dialog box to show log messages from the server. Used with a
 * SungkaRegisterView to capture messages from the server, and places them in
 * this dialog.
 *
 * @author Michael Barrientos
 * @version 0.10, 3/4/2003
 */
public class SungkaRegisterLogDialog extends JDialog implements SungkaConstants {
	/**
	 * The Document associated with the JTextPane. This component shows the log
	 * messages.
	 */
	Document logDocument;

	/**
	 * The EditorKit associated with the TextPane document. Used for inserting
	 * text from an InputStream/Reader
	 */
	EditorKit logEditorKit;

	/** The Action for the close button. Hides dialog without destroying it. */
	Action closeAction = new AbstractAction(resources.getString("GUI_serverlog_close")) {
		{
			putValue(MNEMONIC_KEY, new Integer(KeyEvent.VK_C));
		}
		public void actionPerformed(ActionEvent e) {
			setVisible(false);
		}
	};

	/**
	 * Constructs a new SungkaRegisterLogDialog.
	 * @param parentWindow The parent window of this dialog.
	 */
	public SungkaRegisterLogDialog(Frame parentWindow) {
		super(parentWindow, resources.getString("GUI_serverlog_title"));
		JPanel content = new JPanel();
		content.setLayout(new BorderLayout());
		JTextArea logPane = new JTextArea();
		JScrollPane scrollPane = new JScrollPane(logPane);
		logEditorKit = new DefaultEditorKit();
		logDocument = logPane.getDocument();
		JButton okButton = new JButton(closeAction);
		logPane.setPreferredSize(new Dimension(400, 400));
		content.add(scrollPane, BorderLayout.CENTER);
		content.add(okButton, BorderLayout.SOUTH);
		logPane.setEditable(false);

		// Map escape and enter to close action (NOT to the actual buttons)
		content.getInputMap().put(KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), "close");
		content.getInputMap().put(KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0), "close");
		content.getActionMap().put("close", closeAction);

		setContentPane(content);
		pack();
	}
} // class SungkaRegisterLogDialog
